@@ -4,7 +4,7 @@
 # Copyright (C) 1999-2000 The SourceForge Crew
 # Copyright (C) 2003-2006 Mathieu Roy <yeupou--gna.org>
 # Copyright (C) 2007  Sylvain Beucler
-# Copyright (C) 2017  Ineiev
+# Copyright (C) 2017, 2019 Ineiev
 #
 # This file is part of Savane.
 #
@@ -39,6 +39,9 @@ extract(sane_import('post',
         'form_year',
         'form_usepam')));
 
+$form_email = preg_replace ('/\s/', '', $form_email);
+$form_realname = account_sanitize_realname ($form_realname);
+
 if (isset($GLOBALS['sys_https_host']) && !session_issecure())
   # Force use of TLS for login.
   header('Location: '.$GLOBALS['sys_https_url'].$_SERVER['REQUEST_URI']);
@@ -49,8 +52,6 @@ if (user_isloggedin())
 
 # Block here potential robots.
 dnsbl_check();
-# Block banned IP.
-spam_bancheck();
 
 $login_is_valid = false;
 $pw_is_valid = false;
@@ -223,8 +224,8 @@ actually can read those messages).'). "\n";
         ._("New Account Registration Confirmation")."</h2>\n";
 # TRANSLATORS: the argument is the name of the system (like "Savannah").
       printf(_("Congratulations. You have registered on %s."),
-             $GLOBALS['sys_name'])
-        ."\n".sprintf(_("Your login is %s."),
+             $GLOBALS['sys_name']);
+      print "\n".sprintf(_("Your login is %s."),
           '<strong>'.user_getname($newuserid).'</strong>')."\n";
       print '<p>'
 .sprintf(_("You are now being sent a confirmation email to verify your
@@ -235,8 +236,8 @@ account. The email is sent from &lt;%s&gt;, it contains a text like this:"),
 . $message_head . "XXXXXXXXXXXXXXXXXXXXXXXXX" . $message_tail
 ."\n</pre></blockquote>\n"
 .'<p><em>'
-._("Accounts not confirmed after two days are deleted from the
-database.")."</em></p>\n";
+._("If you don't receive it within a reasonable time, contact website
+administration.")."</em></p>\n";
       }
   }
 # Not valid registration, or first time to page.
@@ -249,8 +250,9 @@ else
     print '<p><span class="preinput">'._("Login Name:")
           .'</span>'."<br />\n".'&nbsp;&nbsp;';
     print form_input("text", "form_loginname", $form_loginname);
+    print '<p><span class="preinput">'.account_password_help().'</span></p>';
     print '<p><span class="preinput">'._("Password / passphrase:")
-           ." ".account_password_help().'</span><br />&nbsp;&nbsp;';
+           .'</span><br />&nbsp;&nbsp;';
     print form_input("password", "form_pw", $form_pw);
     print "</p>\n";
     print '<p><span class="preinput">'._("Re-type Password:")
