@@ -26,8 +26,7 @@ header('Content-Type: text/html; charset=utf-8');
 /* Disallow embedding in any frames.  */
 header('X-Frame-Options: DENY');
 /* Declare more restrictions on how browsers may assemble pages.  */
-header("Content-Security-Policy: default-src 'self'; frame-ancestors 'none'; "
-       ."img-src 'self' static.fsf.org");
+header("Content-Security-Policy: default-src 'self'; frame-ancestors 'none'");
 # Database abstraction.
 require_once(dirname(__FILE__).'/database.php');
 # Security library.
@@ -53,6 +52,7 @@ $sys_dbhost = 'localhost';
 $sys_dbname = 'savane';
 $sys_dbuser = 'root';
 
+$sys_etc_dir = '/etc/savane/';
 $sys_incdir = '/etc/savane/content';
 $sys_appdatadir = '/var/lib/savane';
 $sys_trackers_attachments_dir = $sys_appdatadir . '/trackers_attachments';
@@ -71,6 +71,7 @@ $sys_mail_domain = 'localhost';
 $sys_mail_admin = get_current_user();
 $sys_mail_replyto = "NO-REPLY.INVALID-ADDRESS";
 $sys_email_adress="$sys_mail_admin@$sys_mail_domain";
+$sys_gpg_name = "gpg";
 
 # Debug variables
 # (add them in tests/minimal_configs/Makefile, possibly commented out).
@@ -312,10 +313,6 @@ function get_module_include_dir($script_name, $true_artifact=0, $true_dir=0)
   return $guess;
 }
 
-# HTML layout class, may be overriden by the Theme class.
-require_once(dirname(__FILE__).'/Layout.class');
-
-$HTML = new Layout();
 # Start user session.
 
 # Connect to db.
@@ -339,6 +336,12 @@ non-existing project. Please update the configuration."), FB_ERROR);
 # Determine if they're logged in.
 session_set();
 
+# HTML layout class.
+require_once(dirname(__FILE__).'/Layout.class');
+
+$HTML = new Layout();
+theme_select ();
+
 # If logged in, do a few setups.
 if (user_isloggedin())
   {
