@@ -3,7 +3,7 @@
 #
 # Copyright (C) 2005-2006 Tobias Toedter <t.toedter--gmx.net>
 # Copyright (C) 2005-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2017, 2018 Ineiev
+# Copyright (C) 2017, 2018, 2019 Ineiev
 #
 # This file is part of Savane.
 #
@@ -20,6 +20,141 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+# Return current markup language documentation in Full Markup format.
+function markup_get_reminder ()
+{
+  return
+"== " . _("Tag Scope") . " ==\n\n"
+. str_replace("\n", ' ',
+_("Every markup element should fit in a single line.  For example,
+this text isn't converted in two lines of italics:")) . "\n\n"
+. "+verbatim+\n"
+. _("_First line
+Second line_")
+. "\n-verbatim-\n\n"
+. _("The only exception is the verbatim blocks of text.") . "\n\n"
+. "== " . _("Basic Markup") . " ==\n\n"
+. _("Basic Markup tags are available almost everywhere.") . ' '
+. str_replace("\n", ' ',
+_("Multiple subsequent spaces and newlines are collapsed in Basic markup
+into single spaces. In Rich and Full markup, they are preserved."))
+. "\n\n"
+. _("*bold* markup is:")
+. "\n+verbatim+\n*"
+. _("bold")
+. "*\n-verbatim-\n\n"
+
+. _("_italic_ markup is:")
+
+. "\n+verbatim+\n_"
+. _("italic")
+. "_\n-verbatim-\n\n"
+
+. _("URLs are transformed to links, additionally you can give them a title:")
+. "\n\n"
+. "\n+verbatim+\n"
+. "www.gnu.org
+http://www.fsf.org
+[http://url " . _('Title') . ']'
+. "\n-verbatim-\n\n"
+
+. str_replace("\n", ' ',
+_("Also, these texts are made links to comments
+(within the same item), tracker items and files:"))
+
+. "\n\n+verbatim+\n"
+. "comment #51\n"
+. "bug #1419857\n"
+. "task #289\n"
+. "sr #4913 support #4913\n"
+. "patch #119\n"
+. "file #83521\n"
+. "-verbatim-\n\n"
+
+. str_replace("\n", ' ',
+_("Links to files whose names end in '.png', '.jpg', '.jpeg' (case insensitive)
+are converted to HTML images, the surrounding parentheses and commas (if any)
+are removed:"))
+. "\n\n+verbatim+
+(file #47102)
+-verbatim-\n\n"
+. _("You can add the 'alt' attribute within the parentheses:")
+. "\n\n+verbatim+
+(file #47102 " . _('Flying GNU') . ")
+-verbatim-\n\n"
+. "== " . _("Rich Markup") . " ==\n\n"
+
+. _('Rich Markup tags are available in comments.') . "\n\n"
+
+. _('Unnumbered list markup is:') . "\n\n"
+
+. "+verbatim+\n"
+. _('* item 1
+* item 2
+** item 2 subitem 1
+** item 2 subitem 2
+* item 3')
+. "\n-verbatim-\n\n"
+
+. _('Numbered list markup is:') . "\n\n"
+
+. "+verbatim+\n"
+._('0 item 1
+00 item 1 subitem 1
+0 item 2')
+. "\n-verbatim-\n\n"
+
+. _('Horizontal ruler markup is:') . "\n\n"
+
+. "+verbatim+
+----
+-verbatim-\n\n"
+
+. _('Verbatim markup (useful for code bits) is:') . "\n\n"
+
+. "+verbatim+\n+verbatim+\n"
+. _('seconds = 3600 *days * 24;
+_printf (_("Enter something:"));')
+. "\n-verbatim-\n-verbatim-\n\n"
+. str_replace("\n", ' ',
+_("The starting and ending verbatim marks take whole lines; the rest
+text that may be on the same lines is ignored.")) . "\n\n"
+
+. str_replace("\n", ' ',
+_('The other tag that disables the markup is:')) . "\n\n"
+
+. "+verbatim+\n+nomarkup++verba-nomarkup-tim+\n-verbatim-\n\n"
+
+. str_replace("\n", ' ',
+_('Unlike the verbatim tag, it produces no text block and can be used
+within a line.')) . "\n\n"
+
+. _('Lines starting with ">" are highlighted as quotes:')
+
+. "\n+verbatim+\n> " . _('Quoted line.') . "\n-verbatim-\n\n"
+
+. "== " . _('Full Markup (Heading Tags)') . " ==\n\n"
+
+. str_replace("\n", ' ',
+_("Heading tags are available in rare places like item original
+submissions, news items, project description and user's resume."))
+
+. ' ' . _('First level heading markup is:')
+. "\n\n+verbatim+\n= " . _('Title') . " =\n-verbatim-\n\n"
+
+. _('Second level heading markup is:')
+. "\n\n+verbatim+\n== " . _('Subtitle') . " ==\n-verbatim-\n\n"
+
+. _('Third level heading markup is:')
+
+. "\n\n+verbatim+\n=== " . _('Subsubtitle') . " ===\n-verbatim-\n\n"
+
+. _('Fourth level heading markup is:')
+
+. "\n\n+verbatim+\n==== " . _('Subsubsubtitle') . " ====\n-verbatim-\n\n"
+;
+}
+
 # Functions to allow users to format the text in a secure way:
 #    markup_basic() for very light formatting;
 #    markup_rich() for formatting excepting headers;
@@ -29,9 +164,9 @@
 # Takes as argument the level, being full / rich / basic / none.
 # To avoid making page looking strange, we will put that only on textarea
 # where it is supposed to be the most useful.
-function markup_info($level, $additionnal_string=false)
+function markup_info($level)
 {
-  $link_head = '<a href="/cookbook/?func=detailitem&item_id=125">';
+  $link_head = '<a target="_blank" href="/markup-test.php">';
   $link_tail = '</a>';
 
   if ($level == 'basic')
@@ -63,7 +198,7 @@ function markup_info($level, $additionnal_string=false)
          .'.theme/misc/edit.png"
     border="0" class="icon" alt=""'
          .'
-    />'.$string.$link_tail, $text, true).$additionnal_string.')</span>';
+    />' . $string . $link_tail, $text, true) . ')</span>';
 }
 
 # Convert special markup characters in the input text to real HTML.
@@ -88,7 +223,7 @@ function markup_basic($text)
 
 # Convert special markup characters in the input text to real HTML.
 #
-# This function does the same markup as utils_basic_markup(), plus
+# This function does the same markup as markup_basic(), plus
 # it supports the following:
 # * paragraphs
 # * lists (<ul> and <ol>)
@@ -99,9 +234,19 @@ function markup_rich($text)
   return markup_full($text, false);
 }
 
+# Transform spaces so that they are hopefully preserved in HTML.
+function markup_preserve_spaces ($buf)
+{
+  $buf = preg_replace ('/  *(\n|$)/', '$1', $buf);
+  $buf = preg_replace ('/ /', '&nbsp;', $buf);
+  $buf = preg_replace ('/(([&]nbsp;)*)[&]nbsp;/', '$1 ', $buf);
+  $buf = preg_replace ('/^((<p>)?) /', '$1&nbsp;', $buf);
+  return $buf;
+}
+
 # Convert special markup characters in the input text to real HTML.
 #
-# This function does the same markup as utils_rich_markup(), plus
+# This function does the same markup as markup_rich(), plus
 # it converts headings to <h2> ... <h5>.
 function markup_full($text, $allow_headings=true)
 {
@@ -113,7 +258,7 @@ function markup_full($text, $allow_headings=true)
   $context_stack = array();
 
   $quoted_text = false;
-  $verbatim = false;
+  $verbatim = 0;
   extract(sane_import('request', array('printer')));
   foreach ($lines as $index => $line)
     {
@@ -132,8 +277,6 @@ function markup_full($text, $allow_headings=true)
         {
           $verbatim = 1;
           $verbatim_buffer = '';
-          $verbatim_buffer_linecount = 0;
-
           $line = join("\n", $context_stack);
 
           if (empty($printer))
@@ -151,49 +294,51 @@ function markup_full($text, $allow_headings=true)
       if (preg_match('/([+]verbatim[+])/', $line) and $verbatim)
         $verbatim++;
 
-      if (preg_match('/([-]verbatim[-])/', $line) and $verbatim == 1)
-        {
-          $verbatim = false;
-
-          $line = join("\n", $context_stack);
-          array_shift($context_stack);
-
-          if (empty($printer))
-            {
-              # Limit the textarea to 20 lines.
-              if ($verbatim_buffer_linecount > 20)
-                $verbatim_buffer_linecount = 20;
-
-              # Use a text input if it is not multiline
-              if ($verbatim_buffer_linecount < 2)
-                {
-                  $result[] = '<input type="text" class="verbatim"'
-                              .' readonly="readonly" size="60" value="'
-                              .$verbatim_buffer.'" />';
-                }
-              else
-                {
-                  $result[] = '<textarea class="verbatim" readonly="readonly" rows="'
-                              .$verbatim_buffer_linecount.'" cols="80">'
-                              .$verbatim_buffer.'</textarea>';
-                }
-            }
-          else
-            {
-              $result[] = '<pre class="verbatim">'.$verbatim_buffer.'</pre>';
-            }
-          $verbatim_buffer = '';
-          $verbatim_buffer_linecount = 0;
-
-          # Jump to the next line, assuming that we can ignore the rest of the
-          # line.
-          continue;
-        }
-
       # Decrement the verbatim count if we find a verbatim closing in a
       # verbatim environment.
-      if (preg_match('/([-]verbatim[-])/', $line) and $verbatim > 1)
-        $verbatim--;
+      if (preg_match ('/([-]verbatim[-])/', $line) && $verbatim)
+        {
+          $verbatim--;
+          if ($verbatim == 0)
+            {
+              # End of verbatim: process the block.
+              $line = join("\n", $context_stack);
+              array_shift($context_stack);
+
+              # Unify line breaks.
+              $verbatim_buffer = str_replace ("\r\n", "\n", $verbatim_buffer);
+              $verbatim_buffer = str_replace ("\n\r", "\n", $verbatim_buffer);
+              $verbatim_buffer = str_replace ("\r", "\n", $verbatim_buffer);
+              # Hopefully preserve spaces in HTML allowing line breaking.
+              $verbatim_buffer = str_replace ("\t", "        ",
+                                              $verbatim_buffer);
+              # The first space will be collapsed.
+              $verbatim_buffer = ' ' . markup_preserve_spaces ($verbatim_buffer);
+
+              # Preserve line breaks.
+              $verbatim_buffer = str_replace ("\n", "<br />\n",
+                                              $verbatim_buffer);
+              # Take into account unclosed paragraphs of surrounding text.
+              $closure = "";
+              $aperture = "";
+              $prev_line = "";
+              if (count($result) > 0)
+                $prev_line = $result[count($result) - 1];
+              $len = strlen ($prev_line);
+              if ($len >= 6 && substr ($prev_line, $len - 6) === '<br />')
+                {
+                  $closure = "</p>\n";
+                  $aperture = "<p>";
+                }
+              $result[] = $closure . '<blockquote class="verbatim"><p>'
+                          . $verbatim_buffer . "</p></blockquote>\n" . $aperture;
+              $verbatim_buffer = '';
+
+              # Jump to the next line, assuming that we can ignore the rest of the
+              # line.
+              continue;
+            } # $verbatim == 0
+        } # preg_match ('/([-]verbatim[-])/', $line) && $verbatim
 
       # If we're in the verbatim markup, don't apply the markup.
       if ($verbatim)
@@ -205,14 +350,14 @@ function markup_full($text, $allow_headings=true)
           $escaped_line = str_replace('nomarkup',
             'no-1a4f67a7-4eae-4aa1-a2ef-eecd8af6a997-markup', $line);
           $lines[$index] = $escaped_line;
-          $verbatim_buffer .= $escaped_line;
-          $verbatim_buffer_linecount++;
+          $verbatim_buffer .= $escaped_line . "\n";
         }
       else
         {
           # Otherwise, normal run, do the markup.
-          $result[] = _full_markup($line, $allow_headings, $context_stack,
-                                   $quoted_text);
+          $line = _full_markup($line, $allow_headings, $context_stack,
+                               $quoted_text);
+          $result[] = markup_preserve_spaces ($line);
         }
     }
 
@@ -259,7 +404,7 @@ function markup_full($text, $allow_headings=true)
   # To do this, we need to look for closing tags which have been deleted.
   if ($nomarkup_level > 0)
     {
-      $trailing_markup = array_reverse(split("\n", $last_tags));
+      $trailing_markup = array_reverse(explode ("\n", $last_tags));
       $restored_tags = '';
       foreach ($trailing_markup as $tag)
         {
@@ -323,7 +468,7 @@ function markup_textoutput ($text)
 # Internal function for recognizing and formatting special markup
 # characters in the input line to real HTML.
 #
-# This function is a helper for utils_full_markup() and should
+# This function is a helper for markup_full() and should
 # not be used otherwise.
 function _full_markup($line, $allow_headings, &$context_stack, &$quoted_text)
 {
@@ -371,9 +516,10 @@ function _full_markup($line, $allow_headings, &$context_stack, &$quoted_text)
       # If the previous line was not quoted, start a new quote paragraph.
       if (!$quoted_text)
         {
-          $line = join("\n", $context_stack)."<p class=\"quote\">$line";
+          $line = join("\n", $context_stack)
+                  . "<blockquote><p class=\"quote\">$line";
           # Empty the stack.
-          $context_stack = array('</p>');
+          $context_stack = array('</p></blockquote>');
           $start_paragraph = false;
         }
       $quoted_text = true;
@@ -390,7 +536,7 @@ function _full_markup($line, $allow_headings, &$context_stack, &$quoted_text)
       $quoted_text = false;
     }
   # Don't start a new paragraph again, if we already did that.
-  if (isset($context_stack[0]) && $context_stack[0] == '</p>')
+  if (isset ($context_stack[0]) && substr ($context_stack[0], 0, 4) == '</p>')
     {
       $start_paragraph = false;
     }
@@ -414,7 +560,7 @@ function _full_markup($line, $allow_headings, &$context_stack, &$quoted_text)
       $context_stack = array('</p>');
     }
   # Append a linebreak while in paragraph mode.
-  if (isset($context_stack[0]) && $context_stack[0] == '</p>')
+  if (isset ($context_stack[0]) && substr ($context_stack[0], 0, 4) == '</p>')
     {
       $line .= '<br />';
     }
@@ -569,13 +715,32 @@ function _markup_inline($line)
 
   $comingfrom = '';
   if ($group_id)
-    {
-      $comingfrom = "&amp;comingfrom=$group_id";
-    }
+    $comingfrom = "&amp;comingfrom=$group_id";
 
   if (strlen($line) == 0)
+    return;
+  # Replace references to image files with <img>.
+  preg_match_all ('/\(?((files? ))#(?P<file_id>\d+)'
+                  . '(?P<comment>[^),]*)((\)|, )?)/',
+                  $line, $matches);
+  foreach ($matches['file_id'] as $key => $file_id)
     {
-      return;
+      $result = db_execute("SELECT filename FROM trackers_file
+                            WHERE file_id=? LIMIT 1", array ($file_id));
+      if (!$result || db_numrows ($result) < 1)
+        continue;
+      $file_name = db_result ($result, 0, 0);
+      if (!(preg_match ('/\.(jpe?g|png)$/', strtolower($file_name))))
+        continue;
+      $alt = $matches['comment'][$key];
+      if (substr ($alt, 0, 1) === ' ')
+        $alt = substr ($alt, 1);
+      if ($alt !== '')
+        $alt = 'alt="' . htmlspecialchars ($alt) . '" ';
+      $line = preg_replace ('/\(?((files? ))#' . $file_id . '[^),]*((\)|, )?)/',
+                            '<img src="/file/' . htmlspecialchars ($file_name)
+                            . '?file_id=' . $file_id . '" ' . $alt . '/> ',
+                            $line);
     }
 
   # Regexp of protocols supported in hyperlinks (should be protocols that
