@@ -237,11 +237,17 @@ function sitemenu_thispage($page_title, $page_toptab=0, $page_group=0)
 
   $extraurl = sitemenu_extraurl();
 
-  $HTML->menu_entry($_SERVER['SCRIPT_NAME']."?reload=1".$extraurl,
+  $extra_name = '';
+  if (isset($GLOBALS['extra_script_name']))
+    $extra_name = $GLOBALS['extra_script_name'];
+
+  $HTML->menu_entry($_SERVER['SCRIPT_NAME'] . $extra_name
+                    . "?reload=1" . $extraurl,
                     _("Clean Reload"),
                     1,
                     _("Reload the page without risk of reposting data"));
-  $HTML->menu_entry($_SERVER['SCRIPT_NAME']."?printer=1".$extraurl,
+  $HTML->menu_entry($_SERVER['SCRIPT_NAME'] . $extra_name
+                    . "?printer=1" . $extraurl,
                     _("Printer Version"),
                     1,
                     _("Show this page with a style adapted to printers"));
@@ -307,7 +313,7 @@ function sitemenu_thispage($page_title, $page_toptab=0, $page_group=0)
   # the SQL should not fail - so error reporting works in other usages of db_query.
   $result = db_query("DESCRIBE cookbook_context2recipe");
   $valid_contexts = array();
-  while($row = mysql_fetch_array($result))
+  while ($row = db_fetch_array ($result))
     $valid_contexts[] = $row['Field'];
 
   if (in_array('context_'.CONTEXT, $valid_contexts)
