@@ -132,10 +132,10 @@ function trackers_init($group_id)
   trackers_data_get_all_fields($group_id, true);
 }
 
-function trackers_report_init($group_id, $report_id)
+function trackers_report_init($report_id)
 {
   # Set the global array with report information for faster processing.
-  trackers_data_get_all_report_fields($group_id, $report_id);
+  return trackers_data_get_all_report_fields($report_id);
 }
 
 function trackers_list_all_fields($sort_func=false,$by_field_id=false)
@@ -648,7 +648,9 @@ function trackers_extract_field_list($post_method=true)
         }
       else
         {
-          dbg("Rejected key = ".$key." val = $val");
+          $k = print_r ($key, true);
+          $v = print_r ($val, true);
+          dbg("Rejected key = " . $k . " val = " . $v);
         }
     }
   return($vfl);
@@ -1193,7 +1195,8 @@ function trackers_attach_several_files($item_id, $group_id, &$changes)
         {
           $comment .= "file #$file_id, ";
           $changes['attach'][] = array('name' => $file['name'],
-                                       'size' => $file['size']);
+                                       'size' => $file['size'],
+                                       'id' => $file_id);
         }
     }
 
@@ -1219,6 +1222,8 @@ function trackers_attach_file($item_id,
 {
   global $sys_trackers_attachments_dir;
 
+  $input_file_name = preg_replace ('/[&<\s"\';?!*]/', '@', $input_file_name);
+
   $user_id = (user_isloggedin() ? user_getid(): 100);
 
   if (!is_writable($sys_trackers_attachments_dir))
