@@ -6,7 +6,7 @@
 # Copyright (C) 2003-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2003-2006 Yves Perrin <yves.perrin--cern.ch>
 # Copyright (C) 2007  Sylvain Beucler
-# Copyright (C) 2014, 2017, 2018  Ineiev
+# Copyright (C) 2014, 2017-2019  Ineiev
 #
 # This file is part of Savane.
 #
@@ -24,7 +24,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 # There are parameters that defined before, in the pages that include browse.
-# For instance, $sober is defined by the cookbook/index.php page
+# For instance, $sober is defined by the cookbook/index.php page.
 
 require_once(dirname(__FILE__).'/../trackers/show.php');
 
@@ -42,20 +42,20 @@ extract(sane_import('get', array(
   'history_date_yearfd', 'history_date_monthfd', 'history_date_dayfd',
   'printer', )));
 
-# Number of search criteria (boxes) displayed in one row
+# Number of search criteria (boxes) displayed in one row.
 $fields_per_line=5;
 
-# Avoid undesired user input
+# Avoid undesired user input.
 $browse_preamble = '';
 
 # Number of bugs displayed on screen in one chunk.
-# Default 50
+# Default 50.
 if (!$chunksz)
   $chunksz = 50;
 else
   $chunksz = intval($chunksz);
 
-# Digest mode? Set the digest variable to one
+# Digest mode? Set the digest variable to one.
 if ($func == "digest")
   $digest = 1;
 else
@@ -64,7 +64,7 @@ else
     $func = "browse";
   }
 
-# Make sure offset is defined and has a correct value
+# Make sure offset is defined and has a correct value.
 if (!$offset || $offset < 0)
   $offset = 0;
 else
@@ -76,7 +76,7 @@ $hdr = _('Browse Items');
 # 20.
 # (we will search for items that have score inferior to $spamscore)
 # Default is five. Under 5, an item is not considered to be spam by the
-# system. But users can however decide to use a tougher limit
+# system. But users can however decide to use a tougher limit.
 if (!ctype_digit($spamscore) || $spamscore < 1)
   $spamscore = 5;
 else
@@ -95,19 +95,19 @@ if ($spamscore > 20)
 # ==================================================
 
 # $prefs renamed $url_params to avoid confusion with $pref_arr and $pref_stg
-# used further down
+# used further down.
 $url_params = trackers_extract_field_list(false);
 unset($url_params['group_id']);
 
 # Get rid of url_params['history_date'] which has been included
-# by trackers_extract_field_list
+# by trackers_extract_field_list.
 unset($url_params['history_date']);
 
 # ==================================================
 #   Make sure all URL arguments are captured as array. For simple
 #   search they'll be arrays with only one element at index 0 (this
 #   will avoid to deal with scalar in simple search and array in
-#   advanced which would greatly complexifies the code)
+#   advanced which would greatly complexifies the code).
 # ================================================== */
 while (list($field,$value_id) = each($url_params))
   {
@@ -136,7 +136,7 @@ while (list($field,$value_id) = each($url_params))
       }
   }
 
-# If history event additional constraint is used, add it
+# If history event additional constraint is used, add it.
 if ($history_search)
   # Dates must numeric date, even can be only modified or unmodified
   # If there is crap in there, ignore silently
@@ -158,7 +158,7 @@ if ($history_search)
 #   $order = last sort criteria selected in the UI
 #   $msort = 1 if multicolumn sort activated.
 #  ==================================================
-# if morder not defined then reuse the one in preferences
+# if morder not defined then reuse the one in preferences.
 if (user_isloggedin() && !isset($morder))
   $morder = user_get_preference($preference_prefix.'_browse_order'.$group_id);
 
@@ -179,7 +179,7 @@ if (isset($order))
 if ($morder != '')
   {
   # If the user is logged in, save the wanted order if different from the
-  # current
+  # current.
     if (user_isloggedin())
       if ($morder != user_get_preference($preference_prefix
                                          .'_browse_order'.$group_id))
@@ -214,7 +214,14 @@ if (!$report_id)
     else
       $report_id = 103;
   }
-trackers_report_init($group_id, $report_id);
+
+if (!trackers_report_init($report_id))
+  {
+    fb(sprintf(_("Query form #%s doesn't exist"), $report_id), 1);
+    # Fall back to 'Basic' report.
+    $report_id = 100;
+    trackers_report_init ($report_id);
+  }
 
 # ==================================================
 #  Now see what type of bug set is requested (set is one of none,
@@ -241,7 +248,7 @@ if (!$set)
             while (list(,$expr) = each($pref_arr))
               {
                 # Extract left and right parts of the assignment
-                # and remove the '[]' array symbol from the left part
+                # and remove the '[]' array symbol from the left part.
                 list($field,$value_id) = explode('=',$expr);
                 $field = str_replace('[]','',$field);
                 if ($field == 'advsrch')
@@ -267,7 +274,7 @@ if (!$set)
 
                     # if not args in url (means not after post) ...
                     # set $url_params['history'] explicitly since 'history'
-                    # is not a tracker field and thus wont have been set
+                    # is not a tracker field and thus wont have been set.
                     $url_params['history'][] = $history_search.'>'
                       .$history_field.'>'.$history_event.'>'.$history_date;
                   }
@@ -281,14 +288,14 @@ if (!$set)
 
 if ($set=='my')
   {
-    #  My bugs - backwards compat can be removed 9/10
+    #  My bugs - backwards compat can be removed 9/10.
     $url_params['status_id'][]=1;
     $url_params['assigned_to'][]=user_getid();
   }
 else if ($set=='custom')
   {
   # Use the list of fields built from the arguments and used by the project
-  # (the group_id parameter has been excluded)
+  # (the group_id parameter has been excluded).
   # NB: Note that trackers_extract_field_list function did build and
   #     return date arguments (using _dayfd|monthfd|yearfd boxes) whether
   #     or not they were tracker fields used by the project.
@@ -300,8 +307,8 @@ else if ($set=='custom')
         while (list(,$value_id) = each($arr_val))
           $pref_stg .= '&amp;'.$field.'[]=' . $value_id;
 
-      # build part of the HTML title of this page for more friendly bookmarking
-      # Do not add the criteria in the header if value is "Any"
+      # build part of the HTML title of this page for more friendly bookmarking.
+      # Do not add the criteria in the header if value is "Any".
         if ($value_id != 0)
           {
 # TRANSLATORS: the argument is field name.
@@ -327,30 +334,28 @@ else if ($set=='custom')
 else
   {
     # We want to reset to all open items?
-    # Force the status_id to open, set nothing else, trash the prefes
+    # Force the status_id to open, set nothing else, trash the prefs.
     $url_params['status_id'][]=1;
     user_unset_preference($preference_prefix.'_brow_cust'.$group_id);
   }
 
-# ==================================================
-#   At this point make sure that all paramaters are defined
-#   as well as all the arguments that serves as selection criteria
-#   If not defined then defaults to ANY (0)
-# ==================================================
+# At this point make sure that all paramaters are defined
+# as well as all the arguments that serves as selection criteria
+# If not defined then defaults to ANY (0).
 if (!isset($advsrch))
   $advsrch = 0;
 if (!isset($msort))
   $msort = 0;
 
 # Will be used later to find out if it make sense to look for items of the
-# system group (meaningful on the cookbook)
+# system group (meaningful on the cookbook).
 $not_group_specific = 1;
 
 while ($field = trackers_list_all_fields())
   {
-  # the select boxes for the bug DB search first
+  # The select boxes for the bug DB search first.
     if (trackers_data_is_showed_on_query($field)
-        && trackers_data_is_select_box($field) )
+        && trackers_data_is_select_box($field))
       {
         if (!isset($url_params[$field]))
           $url_params[$field][] = 0;
@@ -371,11 +376,9 @@ while ($field = trackers_list_all_fields())
       }
   }
 
-# ==================================================
-#   Start building the SQL query (select and where clauses)
-# ==================================================
+# Start building the SQL query (select and where clauses).
 
-# Force the selection of priority because it is always shown as color code
+# Force the selection of priority because it is always shown as color code.
 # Force the selection of privacy, we always want to be sure that no private
 # item title is provided to everybody.
 $full_field_list = $col_list = $width_list = $lbl_list = array();
@@ -400,7 +403,7 @@ else
   }
 
 # Take into account the spamscore limit (always shows
-# item posted by the logged in user)
+# item posted by the logged in user).
 $spamscore_additional = '';
 $spamscore_additional_params = array();
 if (user_getid() != 100)
@@ -417,12 +420,12 @@ $where_params = array_merge($where_params, $spam_params);
 # It would be too heavy on the database if this was done very frequently
 # and we already found some project giving direct links to 500 the browse
 # item page with 500 items shown by default.
-# Save the wanted number of chunksz, for later
+# Save the wanted number of chunksz, for later.
 $wanted_chunksz = $chunksz;
 if ($chunksz > 150 && !$printer && !$digest)
   $chunksz = 150;
 
-# No limit on sober output, we want all recipes
+# No limit on sober output, we want all recipes.
 $limit = '';
 $limit_params = array();
 if (!$sober)
@@ -431,10 +434,10 @@ if (!$sober)
     $limit_params = array($offset,$chunksz);
   }
 
-# prepare the where clause with the selection criteria given by the user
+# Prepare the where clause with the selection criteria given by the user.
 reset($url_params);
 
-# prepare for summary and original submission as 'special' criteria
+# Prepare for summary and original submission as 'special' criteria.
 $summary_search = 0;
 $details_search = 0;
 
@@ -442,21 +445,21 @@ while (list($field,$value_id) = each($url_params))
   {
   # If the criteria is not in the field showed on query screen then
   # skip it. This is a sanity check to make sure that the SQL
-  # query we run actually matches the displayed search criteria
+  # query we run actually matches the displayed search criteria.
     if (!trackers_data_is_showed_on_query($field))
       continue;
 
     if (trackers_data_is_select_box($field)
         && !trackers_isvarany($url_params[$field]))
       {
-        # Only select box criteria to where clause if argument is not ANY
+        # Only select box criteria to where clause if argument is not ANY.
         $where .= ' AND '.ARTIFACT.'.'.$field.' IN ('
           .implode(',', array_fill(0, count($url_params[$field]), '?')).') ';
         $where_params = array_merge($where_params, $url_params[$field]);
       }
     else if (trackers_data_is_date_field($field) && $url_params[$field][0])
       {
-      # Transform a date field into a unix time and use <, > or =
+      # Transform a date field into a unix time and use <, > or =.
         list($time,$ok) = utils_date_to_unixtime($url_params[$field][0]);
         preg_match("/\s*(\d+)-(\d+)-(\d+)/", $url_params[$field][0],$match);
         list(,$year,$month,$day) = $match;
@@ -479,7 +482,7 @@ while (list($field,$value_id) = each($url_params))
         else
           {
             $operator = $url_params[$field.'_op'][0];
-            # '=' means that day between 00:00 and 23:59
+            # '=' means that day between 00:00 and 23:59.
             if ($operator == '=')
               {
                 $time_end = mktime(23, 59, 59, $month, $day, $year);
@@ -496,7 +499,7 @@ while (list($field,$value_id) = each($url_params))
               }
           }
 
-      # Always exclude undefined dates (0)
+      # Always exclude undefined dates (0).
         $where .= ' AND '.ARTIFACT.'.'.$field." <> 0 ";
       }
     elseif ((trackers_data_is_text_field($field)
@@ -505,7 +508,7 @@ while (list($field,$value_id) = each($url_params))
       {
       # Buffer summary and original submission (details) to handle them later
       # in case we have an OR to do between the two, instead of the usual
-      # AND
+      # AND.
         if ($sumORdet == 1 &&
             ($field == 'summary' || $field == 'details'))
           {
@@ -516,7 +519,7 @@ while (list($field,$value_id) = each($url_params))
           }
         else
           {
-          # It s a text field accept. Process INT or TEXT,VARCHAR fields differently
+          # It s a text field accept. Process INT or TEXT,VARCHAR fields differently.
             list($expr, $params) =
               trackers_build_match_expression($field, $url_params[$field][0]);
             $where .= " AND $expr ";
@@ -525,7 +528,7 @@ while (list($field,$value_id) = each($url_params))
       }
   }
 
-# Handle summary and/or original submission now, if a AND is required
+# Handle summary and/or original submission now, if a AND is required.
 if ($sumORdet == 1)
   {
   # We will process the usual normal AND case: there was something for both
@@ -572,16 +575,14 @@ if ($sumORdet == 1)
       }
   }
 
-# ==================================================
-#   Loop through the list of used fields to define label and fields/boxes
-#   used as search criteria
-# ==================================================
+# Loop through the list of used fields to define label and fields/boxes
+# used as search criteria.
 
 $ib=0;
 $is=0;
 $load_cal=false;
 
-# Check if summary and original submission are criteria
+# Check if summary and original submission are criteria.
 $summary_search = 0;
 $details_search = 0;
 
@@ -590,15 +591,15 @@ $boxes = '';
 $html_select = '';
 while ($field = trackers_list_all_fields('cmp_place_query'))
   {
-  # Skip unused field
+  # Skip unused field.
     if (!trackers_data_is_used($field))
       continue;
 
-  # Skip fields not part of this query form
+  # Skip fields not part of this query form.
     if (!trackers_data_is_showed_on_query($field))
       continue;
 
-  # beginning of a new row
+  # Beginning of a new row.
     if ($ib % $fields_per_line == 0)
       {
         $align = ($printer ? "left" : "center");
@@ -665,14 +666,14 @@ while ($field = trackers_list_all_fields('cmp_place_query'))
     }
   } # while ($field = trackers_list_all_fields('cmp_place_query'))
 
-# Make sure the last few cells are in the table
+# Make sure the last few cells are in the table.
 if ($labels)
   $html_select .= $labels."</tr>\n".$boxes."</tr>\n";
 
-# Fill the relevant sql bit to be used later
+# Fill the relevant sql bit to be used later.
 # Sensible default case: order by item_id from the recent to the older
 # (only if not in multiple column sort, otherwise dont mess with it because
-# the first thing to be set will matters a lot)
+# the first thing to be set will matters a lot).
 if ($morder == '' && !$msort)
   $morder = "bug_id<";
 $order_by = '';
@@ -705,12 +706,10 @@ if ($morder != '')
       }
   }
 
-# ==================================================
-#   Loop through the list of used fields to see what fields are in the
-#   result table and complement the SQL query accordingly.
-# ==================================================
+# Loop through the list of used fields to see what fields are in the
+# result table and complement the SQL query accordingly.
 
-# Add extra digest column, if necessary
+# Add extra digest column, if necessary.
 if ($digest)
   {
     $col_list[] = "digest";
@@ -732,7 +731,7 @@ while ($field = trackers_list_all_fields('cmp_place_result'))
     $width_list[] = trackers_data_get_col_width($field);
 
   # If we have the field that defines the order, add an icon.
-  # Quite simple in monolcolumn
+  # Quite simple in monolcolumn.
     if (!$msort)
       {
         if ($morder_icon_is_set)
@@ -758,7 +757,7 @@ while ($field = trackers_list_all_fields('cmp_place_result'))
       }
     else
       {
-      # Less simple in multicolumn, indeed
+      # Less simple in multicolumn, indeed.
         $morder_icon_is_set = 0;
         $morder_arr = explode(',',$morder);
         while (list(,$crit) = each($morder_arr))
@@ -773,14 +772,14 @@ while ($field = trackers_list_all_fields('cmp_place_result'))
                   .$so['image'].'.png" alt="'.$so['text']
                   .'" border="0" />';
 
-              # If we found a criteria, go deal with the next column
+              # If we found a criteria, go deal with the next column.
                 $morder_icon_is_set = 1;
                 continue;
               }
           }
 
       # If this field is not a sort criteria, we still have to create
-      # the column
+      # the column.
         if (!$morder_icon_is_set)
           {
             $lbl_list[] = trackers_data_get_label($field);
@@ -789,15 +788,15 @@ while ($field = trackers_list_all_fields('cmp_place_result'))
 
     if (trackers_data_is_username_field($field))
       {
-      # user names requires some special processing to display the username
-      # instead of the user_id
+      # User names requires some special processing to display the username
+      # instead of the user_id.
         $select .= ",user_$field.user_name AS $field";
         $from = "FROM user user_$field, " . substr ($from, 5);
         $where .= " AND user_$field.user_id=".ARTIFACT.".$field ";
       }
     else
       {
-      # otherwise just select this column as is
+      # Otherwise just select this column as is.
         $select .= ",".ARTIFACT.".$field";
       }
   } # while ($field = trackers_list_all_fields('cmp_place_result'))
@@ -834,15 +833,12 @@ if ($history_search)
       }
   }
 
-/* ==================================================
-    Run 2 queries : one to count the total number of results, and the second
+/*  Run 2 queries : one to count the total number of results, and the second
     one with the LIMIT argument. It is faster than selecting all
     rows (without LIMIT) because when the number of bugs is large it takes
     time to transfer all the results from the server to the client.
     It is also faster than using the SQL_CALC_FOUND_ROWS/FOUND_ROWS()
-    capabilities of MySQL
-
-  ================================================== */
+    capabilities of MySQL. */
 $sql_count = "$select_count $from $where";
 $result_count = db_execute($sql_count, array_merge($from_params, $where_params));
 $totalrows = db_result($result_count,0,'count');
@@ -853,10 +849,18 @@ $result = db_execute($sql, array_merge($from_params, $where_params,
 
 # Build the array that will be given to the function that make the item
 # list. We cannot simply return the SQL results, since we have to remove
-# private items if necessary and set $totalrows accordingly
+# private items if necessary and set $totalrows accordingly.
 $result_array = array();
 while ($thisarray = db_fetch_array($result))
   {
+    if (!isset ($thisarray['bug_id']))
+      {
+        $error_msg = 'trackers_run/browse.php: no bug_id in result; $thisarray: ';
+        foreach ($thisarray as $idx => $val)
+          $error_msg .= " [$idx] => '$val'";
+        $error_msg .= "; URI: '" . ($_SERVER['REQUEST_URI']) . "'";
+        error_log ($error_msg);
+      }
   # Get the id.
     $thisitem_id = $thisarray['bug_id'];
 
@@ -870,14 +874,14 @@ while ($thisarray = db_fetch_array($result))
         continue;
       }
 
-  # Build a specific array for each item
+  # Build a specific array for each item.
   $result_array[$thisitem_id] = array();
 
   # Always store the group, it may be necessary later, in case we actually
-  # look for items from different projects
+  # look for items from different projects.
   $result_array[$thisitem_id]["group_id"] = $thisarray["group_id"];
 
-  # Store each field that will be necessary later
+  # Store each field that will be necessary later.
   $nb_of_fields = count($full_field_list);
   for ($k=0; $k<$nb_of_fields; $k++)
     {
@@ -936,7 +940,7 @@ else
     $form_query_type = $report_name;
   }
 
-# Start building the URL that we use to for hyperlink in the form
+# Start building the URL that we use to for hyperlink in the form.
 $url = $GLOBALS['sys_home'].ARTIFACT."/?group="
        .htmlspecialchars ($group)."&amp;func=".htmlspecialchars ($func)
        ."&amp;set=".htmlspecialchars ($set)."&amp;msort="
@@ -951,7 +955,7 @@ $url_nomorder = $url;
 # contains < and > for the sorting order.
 $url .= '&amp;morder='.htmlspecialchars($morder);
 
-# Build the URL for alternate Search
+# Build the URL for alternate Search.
 if ($advsrch)
   {
     $url_alternate_search = str_replace('advsrch=1','advsrch=0',$url);
@@ -963,7 +967,7 @@ else
     $text = _("Advanced Search");
   }
 
-# Select 'list form' or 'select' form
+# Select 'list form' or 'select' form.
 if (!$printer)
   {
     $advsrch_0 = '';
@@ -1007,7 +1011,7 @@ $form .= '<table cellpadding="0" cellspacing="5">
 $form .= $html_select;
 $form .= "</table>\n";
 
-# If both 'summary' and 'original submission' are searched, propose an OR instead of AND
+# If both 'summary' and 'original submission' are searched, propose an OR instead of AND.
 if (($details_search == 1) && ($summary_search == 1))
   {
     if (!$printer)
@@ -1066,15 +1070,15 @@ if (($details_search == 1) && ($summary_search == 1))
     $url .= "&amp;sumOrdet=".htmlspecialchars ($sumORdet);
   }
 
-## Propose to search for field updated since a certain date
+# Propose to search for field updated since a certain date.
 $fextracted = array();
 $fname = array();
 $flabel = array();
 
-# Extract the list of relevant fields
+# Extract the list of relevant fields.
 while ($field = trackers_list_all_fields())
   {
-  # Do not show fields not used by the project
+  # Do not show fields not used by the project.
     if ( !trackers_data_is_used($field))
       continue;
 
@@ -1105,7 +1109,7 @@ $hist_ev_value  = array();
 $hist_ev_value[] = "modified";
 $hist_ev_value[] = "not modified";
 
-# If we are in sober mode, additional constraint is not proposed
+# If we are in sober mode, additional constraint is not proposed.
 if (!$sober)
   {
     $form_separator = '';
@@ -1151,14 +1155,22 @@ if (!$sober)
                                           false);
       }
     else if ($history_search)
-      # In printer mode, if the additional constrait is off,
-      # no need to print it
+      # In printer mode, if the additional constraint is off,
+      # no need to print it.
       {
+        $form_activated =
 # TRANSLATORS: this string is used as the argument in
 # 'Additional constraint %s'.
-        $form_activated = _("activated");
+                          _("activated");
         $form_fieldname = $flabel[$history_field];
-        $form_modified = $hist_ev_text[$history_event];
+        $form_modified = $hist_ev_text[0];
+        $rows = count($hist_ev_text);
+        for ($i = 0; $i < $rows; $i++)
+          if ($hist_ev_value[$i] == $history_event)
+            {
+              $form_modified = $hist_ev_text[$i];
+              break;
+            }
         $form_since = trackers_field_date('history_date',
                                           $history_date,
                                           0,
@@ -1187,8 +1199,8 @@ if ($history_search)
           .htmlspecialchars ($history_event)."&amp;history_date="
           .htmlspecialchars ($history_date);
 
-# Number of items printed at once
-# In sober mode, they are all printed
+# Number of items printed at once.
+# In sober mode, they are all printed.
 if (!$sober)
   {
     if (!$printer)
@@ -1225,7 +1237,7 @@ if (!$sober)
   }
 
 # In sober mode, do not talk about sorting order, we will anyway not use
-# tables to sort the items
+# tables to sort the items.
 if ($totalrows > 0 && !$sober)
   {
     $form .= '<p class="smaller">';
@@ -1263,12 +1275,10 @@ _("You can also <a href=\"%s\">activate multicolumn sort</a>."),
     $form .= "</p>\n";
   }
 
-# Print the form
+# Print the form.
 print html_show_displayoptions($form,$form_opening,$form_submit);
 
-/* ==================================================
-  Finally display the result table
- ================================================== */
+# Finally display the result table.
 
 if ($digest)
   print '<form action="'.htmlentities ($_SERVER['PHP_SELF']).'" method="get">
