@@ -3,7 +3,7 @@
 #
 # Copyright (C) 1999-2000 The SourceForge Crew
 # Copyright (C) 2004-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2017 Ineiev
+# Copyright (C) 2017, 2019 Ineiev
 #
 # This file is part of Savane.
 #
@@ -22,7 +22,7 @@
 
 require_once(dirname(__FILE__).'/member.php');
 
-# Unset these globals until register_globals if off everywhere
+# Unset these globals until register_globals if off everywhere.
 unset($USER_IS_SUPER_USER);
 $USER_RES=array();
 
@@ -39,7 +39,7 @@ function user_can_be_super_user()
   global $USER_IS_SUPER_USER;
 # Members of sys_group_id  are admins and have super-user privs site-wide.
   if (isset($USER_IS_SUPER_USER))
-      return $USER_IS_SUPER_USER;
+    return $USER_IS_SUPER_USER;
   if (user_isloggedin())
     {
       $result=db_execute("SELECT * FROM user_group WHERE user_id=? "
@@ -151,8 +151,9 @@ function user_getname($user_id=0, $getrealname=0)
     }
   # Use current user if one is not passed in.
   if (!$user_id && $getrealname == 0)
-# TRANSLATORS: "Not applicable".
-    return ($G_USER?$G_USER['user_name']:_("NA"));
+    return ($G_USER?$G_USER['user_name']:
+            # TRANSLATORS: "Not applicable".
+                                         _("NA"));
 
   if ($user_id == 0)
     {
@@ -209,6 +210,20 @@ function user_exists($user_id, $squad_only=false)
   return false;
 }
 
+function user_is_active ($user_id)
+{
+  $result = user_get_result_set ($user_id);
+  if ($result && db_numrows($result) > 0)
+    return db_result ($result, 0, "status") == 'A';
+  return false;
+}
+
+function user_fetch_name ($user_id)
+{
+  $name = user_get_field ($user_id, 'user_name');
+  return ($name === false)? '': $name;
+}
+
 function user_getrealname($user_id=0, $rfc822_compliant=0)
 {
   $ret = user_getname($user_id, 1);
@@ -221,12 +236,16 @@ function user_getrealname($user_id=0, $rfc822_compliant=0)
 
 function user_getemail($user_id=0)
 {
-  if (!$user_id)
-    $user_id = user_getid();
+  return user_get_field ($user_id, 'email');
+}
 
-  $result = user_get_result_set($user_id);
-  if ($result && db_numrows($result) > 0)
-      return db_result($result,0,"email");
+function user_get_field ($user_id, $field)
+{
+  if (!$user_id)
+    $user_id = user_getid ();
+  $result = user_get_result_set ($user_id);
+  if ($result && db_numrows ($result) > 0)
+    return db_result ($result, 0, $field);
   return false;
 }
 
@@ -370,9 +389,7 @@ function user_use_votes ($user_id=false)
   $result = db_execute("SELECT vote_id FROM user_votes WHERE user_id=?",
                        array($user_id));
   if (db_numrows($result) > 0)
-    {
-      return true;
-    }
+    return true;
   return false;
 }
 
@@ -415,7 +432,81 @@ function user_guess ()
   return true;
 }
 
-# Function that should always be used to remove an user account
+# Return true when account has any traces in the trackers and group_history,
+# so it should not be removed from the database.
+function user_has_history ($user_id)
+{
+  $trackers = array ('bugs', 'support', 'task', 'patch', 'cookbook');
+  $name = user_fetch_name ($user_id);
+  if ($name == '')
+    return false;
+  foreach ($trackers as $tr)
+    {
+      $result = db_execute ("SELECT bug_id FROM $tr WHERE submitted_by=? LIMIT 1",
+                            array ($user_id));
+      if ($result && db_numrows ($result) > 0)
+        return true;
+      $result = db_execute ("SELECT bug_history_id FROM "
+                             .$tr."_history WHERE mod_by=? LIMIT 1",
+                            array ($user_id));
+      if ($result && db_numrows ($result) > 0)
+        return true;
+    }
+  $result = db_execute (
+"SELECT group_history_id FROM group_history
+ WHERE
+   mod_by=?
+   OR
+    (old_value=?
+     AND
+     (field_name='Added User'
+      OR field_name='User Requested Membership'
+      OR field_name='Removed User'
+      OR field_name='Changed User Permissions'
+      OR field_name LIKE 'Added User to Squad %'
+      OR field_name LIKE 'Removed User from Squad %'
+      OR field_name='Approved User'))
+ LIMIT 1", array ($user_id, $name));
+  if ($result && db_numrows ($result) > 0)
+    return true;
+  return false;
+}
+
+# Completely remove account from the database; should only be done
+# when there was no activity related to the account on trackers
+# and in group_history.
+function user_purge ($user_id)
+{
+  db_execute ("DELETE FROM user where user_id=?", array($user_id));
+}
+
+# Rename account, with necessary history adjustments in the database (unless
+# that would raise any concerns).
+function user_rename ($user_id, $new_name)
+{
+  $old_name = user_fetch_name ($user_id);
+  if ($old_name == '')
+    return sprintf ('No user #%i in the database', $user_id);
+  if (db_numrows(db_execute("SELECT user_id FROM user WHERE user_name = ?",
+                            array($new_name))) > 0)
+    return sprintf ('User <%s> alredy exists', $new_name);
+  db_execute ("UPDATE user SET user_name=? WHERE user_id=?",
+              array($new_name, $user_id));
+  # In fact, only the first two field_name values may occur, because the user
+  # has never been added to any group.
+  db_execute ("UPDATE group_history set old_value=?
+                      WHERE old_value=?
+                        AND (field_name='User Requested Membership'
+                             OR field_name='Removed User'
+                             OR field_name='Added User'
+                             OR field_name LIKE 'Added User to Squad %'
+                             OR field_name LIKE 'Removed User from Squad %'
+                             OR field_name='Approved User')",
+              array ($new_name, $old_name));
+  return '';
+}
+
+# Function that should always be used to remove an user account.
 # This function should always be used in a secure context, when user_id
 # is 100% sure.
 # Best is to not to pass the user_id argument unless necessary.
@@ -427,11 +518,9 @@ function user_delete ($user_id=false, $confirm_hash=false)
   # Serious deal, serious check of credentials: allowed only to superuser
   # and owner of the account.
   if (!user_is_super_user() && $user_id != user_getid())
-    {
-      exit_permission_denied();
-    }
+    exit_permission_denied();
 
-  # If self-destruct, the correct confirm_hash must be provided
+  # If self-destruct, the correct confirm_hash must be provided.
   if (!user_is_super_user())
     {
       $confirm_hash_test = " confirm_hash=? AND ";
@@ -443,9 +532,19 @@ function user_delete ($user_id=false, $confirm_hash=false)
       $confirm_hash_param = array();
     }
 
+  if (!user_has_history ($user_id))
+    {
+      user_purge ($user_id);
+      fb(_("Account deleted."));
+      return true;
+    }
+
+  $new_realname = '-*-';
+  if ($user_id == user_getid ())
+    $new_realname = '-';
   $success = db_autoexecute('user',
    array('user_pw' => '!',
-         'realname' => '-X-',
+         'realname' => $new_realname,
          'status' => 'S',
          'email' => 'idontexist@example.net',
          'confirm_hash' => '',
@@ -459,25 +558,27 @@ function user_delete ($user_id=false, $confirm_hash=false)
    DB_AUTOQUERY_UPDATE,
    "$confirm_hash_test user_id=?", array_merge($confirm_hash_param,
                                                array($user_id)));
-  if ($success)
+  if (!$success)
     {
-      # Remove from any groups, if by any chances this was not done before
-      # (normally, an user must quit groups before being allowed to delete his
-      # account).
-      db_execute("DELETE FROM user_group WHERE user_id=?", array($user_id));
-      db_execute("DELETE FROM user_squad WHERE user_id=?", array($user_id));
-
-      # Additionally, clean up sessions, remove prefs
-      db_execute("DELETE FROM user_bookmarks WHERE user_id=?", array($user_id));
-      db_execute("DELETE FROM user_preferences WHERE user_id=?", array($user_id));
-      db_execute("DELETE FROM user_votes WHERE user_id=?", array($user_id));
-      db_execute("DELETE FROM session WHERE user_id=?", array($user_id));
-
-      fb(_("Account deleted."));
-      return true;
+      fb(_("Failed to update the database."), 1);
+      return false;
     }
+  # Remove from any groups, if by any chances this was not done before
+  # (normally, an user must quit groups before being allowed to delete his
+  # account).
+  db_execute("DELETE FROM user_group WHERE user_id=?", array($user_id));
+  db_execute("DELETE FROM user_squad WHERE user_id=?", array($user_id));
 
-  fb(_("Failed to update the database."), 1);
-  return false;
+  # Additionally, clean up sessions, remove prefs
+  db_execute("DELETE FROM user_bookmarks WHERE user_id=?", array($user_id));
+  db_execute("DELETE FROM user_preferences WHERE user_id=?", array($user_id));
+  db_execute("DELETE FROM user_votes WHERE user_id=?", array($user_id));
+  db_execute("DELETE FROM session WHERE user_id=?", array($user_id));
+  # Rename user; the name starts with '_' so it can't be registered manually,
+  # and it shall be unique because it's derived from $user_id.
+  user_rename($user_id, "_$user_id");
+
+  fb(_("Account deleted."));
+  return true;
 }
 ?>
