@@ -157,8 +157,8 @@ function run_gpg_checks ($key)
 {
   $ret = "";
   $ret .= "<h2>"._("GnuPG version")."</h2>\n";
-  $gpg_name = 'gpg';
-  $cmd = $gpg_name . " --version";
+  $gpg_name = "'" . $GLOBALS['sys_gpg_name'] . "'";
+  $cmd = $gpg_name . ' --version';
   $d_spec = array (0 => array("pipe", "r"), 1 => array("pipe", "w"),
                    2 => array("file", "/dev/null", "a"));
 
@@ -223,7 +223,7 @@ if ($update)
           fb(_("You must supply a new real name."), 1);
         else
           {
-            $newvalue = strtr($newvalue, "\'\"\,", "     ");
+            $newvalue = account_sanitize_realname ($newvalue);
             $success = db_autoexecute('user', array('realname' => $newvalue),
                                       DB_AUTOQUERY_UPDATE,
                                       "user_id=?", array(user_getid()));
@@ -328,6 +328,7 @@ if ($update)
         if (!$step)
           {
             require_once('../../include/account.php');
+            $newvalue = preg_replace ('/\s/', '', $newvalue);
             # Proceed only if it is a valid email address.
             if (account_emailvalid($newvalue))
               {
