@@ -3,7 +3,7 @@
 #
 # Copyright (C) 1999-2000 The SourceForge Crew
 # Copyright (C) 2004-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2017 Ineiev
+# Copyright (C) 2017, 2019 Ineiev
 #
 # This file is part of Savane.
 #
@@ -35,7 +35,9 @@ if (!$result || (db_numrows($result) < 1))
   exit_error(_("User not found"));
 elseif (db_result($result,0,'people_view_skills') != 1)
   exit_error(_("This user deactivated his/her Resume & Skills page"));
-elseif (db_result($result,0,'status') == 'D' && !user_is_super_user())
+elseif ((db_result($result,0,'status') == 'D'
+         || db_result($result,0,'status') == 'S')
+        && !user_is_super_user())
   exit_error(_("This account was deleted."));
 # TRANSLATORS: the argument is user's name.
 site_header(array('title'=>sprintf(_("%s Resume & Skills"),
@@ -49,11 +51,14 @@ print '<p>'.sprintf(_("Follows Resume & Skills of %s."),
 ';
 utils_get_content("people/viewprofile");
 
-print '<h2>'._("Resume")."</h2>\n";
-print markup_full(htmlspecialchars(db_result($result,0,'people_resume')));
-
-print '<h2>'._("Skills")."</h2>\n";
-print people_show_skill_inventory($user_id);
+$resume = db_result ($result, 0, 'people_resume');
+if ($resume != '')
+  {
+    print '<h2>' . _("Resume") . "</h2>\n";
+    print markup_full (htmlspecialchars ($resume));
+  }
+print '<h2>' . _("Skills") ."</h2>\n";
+print people_show_skill_inventory ($user_id);
 
 site_footer(array());
 ?>
