@@ -1,23 +1,23 @@
 <?php
-# Edit user's groups.
-# 
+# Edit user's groups, email &c.
+#
 # This file is part of the Savane project
-# 
+#
 # Copyright (C) 1999-2000 The SourceForge Crew
-# Copyright (C) 2017, 2018 Ineiev
-# 
+# Copyright (C) 2017, 2018, 2019 Ineiev
+#
 # This file is part of Savane.
-# 
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
 # License, or (at your option) any later version.
-# 
+#
 # Savane is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU Affero General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
@@ -35,7 +35,7 @@ session_require(array('group'=>'1','admin_flags'=>'A'));
 $HTML->header(array('title'=>no_i18n('Admin: User Info')));
 
 extract(sane_import('request', array('user_id', 'action')));
-extract(sane_import('post', array('admin_flags', 'email')));
+extract(sane_import('post', array('admin_flags', 'email', 'new_name')));
 
 if ($action=='remove_user_from_group')
   {
@@ -60,7 +60,7 @@ elseif ($action=='update_user_group')
 elseif ($action=='update_user')
   {
     $result=db_execute("UPDATE user SET email=? WHERE user_id=?",
-                       array($email, $user_id));
+                       array(preg_replace ('/\s/', "", $email), $user_id));
     if (!$result || db_affected_rows($result) < 1)
       fb(no_i18n('Error Updating User:').$result.' '.db_error(), 1);
     else
@@ -76,6 +76,26 @@ elseif ($action=='add_user_to_group')
     else
       fb(no_i18n('Successfully added user to group'));
   }
+elseif ($action == 'rename')
+  {
+    if (!account_namevalid ($new_name))
+      {
+        fb(no_i18n(sprintf('New account name <%s> is invalid', $new_name), 1));
+      }
+    else
+      {
+        $res = user_rename ($user_id, $new_name);
+        if ('' == $res)
+          {
+            fb(no_i18n('Successfully renamed account to '). $new_name);
+          }
+        else
+          {
+            fb(no_i18n('Error renaming account to <'. $new_name . '>:' . $res),
+                       1);
+          }
+      }
+  }
 
 # Get user info.
 $res_user = db_execute("SELECT * FROM user WHERE user_id=?", array($user_id));
@@ -83,24 +103,41 @@ $row_user = db_fetch_array($res_user);
 
 print '
 <p>'.no_i18n('Savannah User Group Edit for user:').' <strong>'
-.$user_id. ' ' .user_getname($user_id).'</strong></p>
-<p>
+.$user_id. ' ' .user_getname($user_id)."</strong></p>\n";
+if ($row_user['status'] == 'SQD')
+  print '<p>'.no_i18n('Account info: this is a squad.').'</p>';
+else
+  {
+   print
+'<p>
 '.no_i18n('Account Info:').'
 <form method="post" action="'.htmlentities ($_SERVER['PHP_SELF']).'">
 <input type="hidden" name="action" value="update_user">
 <input type="hidden" name="user_id" value="'.htmlspecialchars($user_id).'">
 </p>
-<p>
+<p>Email:
 <input type="text" title="'.no_i18n("Email").'" name="email" value="'
 .htmlspecialchars($row_user['email']).'" size="25" maxlength="55">
-
+</p>
 <p>
 <input type="submit" name="Update_Unix" value="'.no_i18n('Update').'">
 </p>
 </form>
-<hr />
-
+<form method="post" action="'.htmlentities ($_SERVER['PHP_SELF']).'">
+<input type="hidden" name="action" value="rename">
+<input type="hidden" name="user_id" value="'.htmlspecialchars($user_id).'">
+<p>Account name:
+<input type="text" title="'.no_i18n("New name").'" name="new_name" value="'
+. htmlspecialchars ($row_user['user_name']) . '" size="25" maxlength="55">
+</p>
 <p>
+<input type="submit" name="'.no_i18n('Update_Name').'" value="'
+ .no_i18n('Rename').'">
+</p>
+</form>
+<hr />';
+  } #  $row_user['status'] != 'SQD'
+print '
 <h2>'.no_i18n('Current Groups').'</h2>
 ';
 
@@ -113,6 +150,14 @@ $res_cat = db_execute("SELECT groups.group_name AS group_name, "
 
 while ($row_cat = db_fetch_array($res_cat))
   {
+    if ($row_user['status'] == 'SQD')
+      {
+        print "<br />\n"
+         . '<a href="/project/admin/squadadmin.php?squad_id='
+         . htmlspecialchars($user_id) . '&group_id=' . $row_cat['group_id']
+         . '">' . group_getname($row_cat['group_id']) . "</a>\n";
+        continue;
+      }
     print ("<br /><hr /><strong>"
          . group_getname($row_cat['group_id']) . "</strong> "
          . "<a href=\"usergroup.php?user_id="
@@ -135,9 +180,10 @@ while ($row_cat = db_fetch_array($res_cat))
 </form>
 ';
   }
-
+if ($row_user['status'] != 'SQD')
+  {
 # Show a form so a user can be added to a group.
-print '
+  print '
 <hr />
 <p>
 <form action="'.htmlentities ($_SERVER['PHP_SELF']).'" method="post">
@@ -156,6 +202,7 @@ print '
 .htmlspecialchars($user_id).'">['.no_i18n('Change User\'s Password').']</a>
 </p>
 ';
+  }
 
 html_feedback_bottom($feedback);
 $HTML->footer(array());
